<?php


class RSPW_Product_Quantity_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {
		$rule_quantity = intval( $rule['value_quantity'] );
		$operator      = RSPW_Operators_Factory::make( $rule['operator'] );

		$total_quantity = array_reduce(
			$package,
			function ( $total, $item ) {
				return $total + $item['quantity'];
			},
			0
		);
		return $operator->match( $rule_quantity, $total_quantity );
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_GT    => __( 'more than', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_EQUAL => __( 'equal to', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_LT    => __( 'less than', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	/**
	 * @return array
	 */
	public function get_meta_box_fields() {
		return array(
			array(
				'name'    => __( 'Total quantity of items', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'      => 'value_quantity',
				'type'    => 'text_small',
				'classes' => 'value_field quantity',
			),
		);
	}
}
