<?php


class RSPW_Product_Tag_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {
		$rule_product_tag = $rule['value_product_tag'];
		$operator         = RSPW_Operators_Factory::make( $rule['operator'] );

		foreach ( $package as $item_id => $content ) {
			/** @var WC_Product $product */
			$product    = $content['data'];
			$product_id = $product->get_id();
			$parent_id  = $product->get_parent_id();
			if ( $parent_id > 0 ) {
				$product_id = $parent_id;
			}
			$terms = get_the_terms( $product_id, 'product_tag' );
			if ( ! $terms ) {
				continue;
			}

			$product_tags = array_map(
				function ( $term ) {
					return $term->term_id;
				},
				$terms
			);

			if ( $operator->match( $rule_product_tag, $product_tags ) ) {
				return true;
			}
		}

		return false;
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_IN     => __( 'in', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_NOT_IN => __( 'not in', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	/**
	 * @return array
	 */
	public function get_meta_box_fields() {
		return array(
			array(
				'name'             => __( 'Product Tags', 'restricted-shipping-and-payment-for-woocommerce' ),
				'desc'             => __( 'Select product tag/s', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'               => 'value_product_tag',
				'type'             => 'pw_multiselect',
				'show_option_none' => false,
				'options'          => $this->get_product_tags(),
				'classes'          => 'value_field product_tag',
			),
		);
	}

	/**
	 * @return array
	 */
	private function get_product_tags() {
		$arguments = array(
			'taxonomy'   => 'product_tag',
			'orderby'    => 'name',
			'order'      => 'desc',
			'hide_empty' => false,
		);

		$product_tags = get_terms( $arguments );

		$tags = array();
		/** @var WP_Term $tag */
		foreach ( $product_tags as $tag ) {
			$tags[ $tag->term_id ] = $tag->name;
		}

		return $tags;
	}
}
